searchData={"items":[{"type":"module","title":"Exceed","doc":"Exceed is a high-level stream-oriented library for generating Excel files.\nIt may be useful when generating spreadsheets from data sets that exceed\navailable memory—or exceed the memory that one wishes to devote to\ngenerating Excel files.","ref":"Exceed.html"},{"type":"module","title":"Examples - Exceed","doc":"``` elixir\niex> rows = Stream.repeatedly(fn -> [:rand.uniform(), :rand.uniform()] end)\niex> stream = Exceed.Workbook.new(\"creator name\")\n...>   |> Exceed.Workbook.add_worksheet(\n...>     Exceed.Worksheet.new(\"Sheet\", [\"header a\", \"header b\"], Enum.take(rows, 10)))\n...>   |> Exceed.stream!()\n...>\niex> zip = stream |> Enum.to_list() |> IO.iodata_to_binary()\niex> {:ok, package} = XlsxReader.open(zip, [source: :binary])\niex> XlsxReader.sheet_names(package)\n[\"Sheet\"]\n```","ref":"Exceed.html#module-examples"},{"type":"function","title":"Exceed.stream!/1","doc":"Convert an `Exceed.Workbook` to a stream.","ref":"Exceed.html#stream!/1"},{"type":"module","title":"Exceed.Util","doc":"Helpers for converting Elixir data formats to Excel","ref":"Exceed.Util.html"},{"type":"function","title":"Exceed.Util.to_excel_datetime/1","doc":"Converts a DateTime to a float representing days since 1900, correcting for the Lotus 123 bug","ref":"Exceed.Util.html#to_excel_datetime/1"},{"type":"type","title":"Exceed.Util.erl_datetime_t/0","doc":"","ref":"Exceed.Util.html#t:erl_datetime_t/0"},{"type":"module","title":"Exceed.Workbook","doc":"The top-level structure for collecting structures that will be converted to an\nExcel file.","ref":"Exceed.Workbook.html"},{"type":"module","title":"Examples - Exceed.Workbook","doc":"``` elixir\niex> Exceed.Workbook.new(\"creator name\")\n#Exceed.Workbook \n```\n\n``` elixir\niex> headers = [\"header 1\"]\niex> rows = Stream.repeatedly(fn -> [:rand.uniform(), :rand.uniform()] end)\niex> ws = Exceed.Worksheet.new(\"Sheet Name\", headers, rows)\n...>\niex> Exceed.Workbook.new(\"creator name\")\n...>  |> Exceed.Workbook.add_worksheet(ws)\n#Exceed.Workbook \n```","ref":"Exceed.Workbook.html#module-examples"},{"type":"function","title":"Exceed.Workbook.add_worksheet/2","doc":"Adds an `Exceed.Worksheet` to the workbook.","ref":"Exceed.Workbook.html#add_worksheet/2"},{"type":"function","title":"Exceed.Workbook.new/1","doc":"Initialize a new workbook with a creator name.","ref":"Exceed.Workbook.html#new/1"},{"type":"type","title":"Exceed.Workbook.t/0","doc":"","ref":"Exceed.Workbook.html#t:t/0"},{"type":"module","title":"Exceed.Worksheet","doc":"Worksheets represent the tabular data to be included in an Excel sheet, in\naddition to metadata about the sheet and how it should be rendered.","ref":"Exceed.Worksheet.html"},{"type":"module","title":"Examples - Exceed.Worksheet","doc":"``` elixir\niex> headers = [\"header 1\"]\niex> rows = [[\"row 1\"], [\"row 2\"]]\niex> ws = Exceed.Worksheet.new(\"Sheet Name\", headers, rows)\n#Exceed.Worksheet \n...>\niex> Exceed.Workbook.new(\"creator name\")\n...>  |> Exceed.Workbook.add_worksheet(ws)\n#Exceed.Workbook \n```","ref":"Exceed.Worksheet.html#module-examples"},{"type":"module","title":"Sheet content - Exceed.Worksheet","doc":"Rows are represented by an enumerable where each row will be resolved to a\nlist of cells. In the above example, a list of lists is provided.\nAlternatively, a stream may be provided.\n\n``` elixir\niex> stream = Stream.repeatedly(fn -> [:rand.uniform(), :rand.uniform()] end)\n...>\niex> %Worksheet{} =\n...>     Exceed.Worksheet.new(\"Sheet Name\", [\"Random 1\", \"Random 2\"], stream)\n```","ref":"Exceed.Worksheet.html#module-sheet-content"},{"type":"module","title":"Sheet options - Exceed.Worksheet","doc":"When initializing a worksheet, default options may be overridded by providing\nan options via the optional fourth argument to `Exceed.Worksheet.new/4`.\n\n``` elixir\niex> headers = [\"header 1\"]\niex> rows = [[\"row 1\"], [\"row 2\"]]\niex> opts = [cols: [padding: 6.325]]\niex> %Worksheet{} = Exceed.Worksheet.new(\"Sheet Name\", headers, rows, opts)\n```\n\n- Column padding - `cols: [padding: value]` - default: `4.25` - extra space\n  given to each column, in addition to whatever is determined from the\n  headers or the specified widths.\n- Column width - `cols: [widths: %{1 => 15.75}]` - specify the exact width\n  of specific columns as a map of 1-indexed column indexes to width as a\n  float. When not provided, this is automatically determined from the\n  character length of the relevant header cell, or from the first row when\n  no headers are provided.\n\n#","ref":"Exceed.Worksheet.html#module-sheet-options"},{"type":"module","title":"Column widths - Exceed.Worksheet","doc":"1. Note that the actual rendered width of a cell depends on the character\n  width of the applied font, on the computer used to open the spreadsheet (see\n  the [OpenXML.Spreadsheet Column docs](https://learn.microsoft.com/en-us/dotnet/api/documentformat.openxml.spreadsheet.column?view=openxml-3.0.1)\n  for more info).","ref":"Exceed.Worksheet.html#module-column-widths"},{"type":"function","title":"Exceed.Worksheet.new/4","doc":"Initialize a new worksheet to be added to a workbook. See `Exceed.Workbook.add_worksheet/2`.\nFor worksheet options, see the module docs for `m:Exceed.Worksheet#module-sheet-options`.","ref":"Exceed.Worksheet.html#new/4"},{"type":"function","title":"Examples - Exceed.Worksheet.new/4","doc":"``` elixir\niex> headers = [\"header 1\"]\niex> rows = [[\"row 1\"], [\"row 2\"]]\niex> opts = [cols: [padding: 6.325]]\niex> %Worksheet{} = Exceed.Worksheet.new(\"Sheet Name\", headers, rows, opts)\n```","ref":"Exceed.Worksheet.html#new/4-examples"},{"type":"type","title":"Exceed.Worksheet.columns_option/0","doc":"","ref":"Exceed.Worksheet.html#t:columns_option/0"},{"type":"type","title":"Exceed.Worksheet.headers/0","doc":"","ref":"Exceed.Worksheet.html#t:headers/0"},{"type":"type","title":"Exceed.Worksheet.spreadsheet_option/0","doc":"","ref":"Exceed.Worksheet.html#t:spreadsheet_option/0"},{"type":"type","title":"Exceed.Worksheet.spreadsheet_options/0","doc":"","ref":"Exceed.Worksheet.html#t:spreadsheet_options/0"},{"type":"type","title":"Exceed.Worksheet.t/0","doc":"","ref":"Exceed.Worksheet.html#t:t/0"},{"type":"exception","title":"Exceed.Error","doc":"","ref":"Exceed.Error.html"},{"type":"extras","title":"Exceed","doc":"# Exceed\n\n`Exceed` is a high-level stream-oriented library for generating Excel files.\nUseful when generating spreadsheets from data sets large enough that they may\nexceed available memory—or at least the available memory that one might want\nto dedicate to building spreadsheets.","ref":"readme.html"},{"type":"extras","title":"Installation - Exceed","doc":"``` elixir\ndef deps do\n  [\n    {:exceed, \"~> 0.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Exceed","doc":"XLSX streams are generated by initializing a workbook (with a creator name),\nadding worksheets, and then converting that to a stream.\n\n``` elixir\nstream =\n  Exceed.Workbook.new(\"Creator Name\")\n  |> Exceed.Workbook.add_worksheet(\n    Exceed.Worksheet.new(\"Sheet Name\", [\"Heading 1\", \"Heading 2\"]\n      [[\"Row 1 Cell 1\", \"Row 1 Cell 2\"], [\"Row 2 Cell 1\", \"Row 2 Cell 2\"]])\n  )\n  |> Exceed.stream!()\n\nstream\n|> Stream.into(File.stream!(\"/tmp/workbook.xslx\"))\n|> Stream.run()\n```\n\nWorksheets may be initialized with lists of lists, or they may be initialized\nwith a stream of data that maps to a list of cells.\n\n``` elixir\nrows =\n  Stream.unfold(1, fn\n    10_001 -> nil\n    row_count -> {[\"Row #{row_count} Cell 1\", \"Row #{row_count} Cell 2\"], row_count + 1}\n  end)\n\nExceed.Worksheet.new(\"Sheet Name\", [\"Heading 1\", \"Heading 2\"], rows)\n```","ref":"readme.html#usage"},{"type":"extras","title":"Alternatives & References - Exceed","doc":"This library is inspired by and learns from other great libraries. One may\nchoose to use those instead of Exceed:\n\n- [elixlsx](https://hex.pm/packages/elixlsx) - Provides fine-grained control\n  over cells, but is not stream-oriented and thus requires that all source data\n  and rows be retained in memory until the entire workbook is written.\n- [xml_stream](https://hex.pm/packages/xml_stream) - Provides low-level\n  constructs that may be combined to make an Excel file. Works nicely with\n  streams. Requires that one know all the ins and outs of\n  [SpreadsheetML](https://learn.microsoft.com/en-us/office/open-xml/spreadsheet/structure-of-a-spreadsheetml-document?tabs=cs)\n  in order to make a valid file that Excel can parse.","ref":"readme.html#alternatives-references"},{"type":"extras","title":"LICENSE","doc":"Copyright 2024 synchronal.dev\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of this software and associated\ndocumentation files (the \"Software\"), to deal in the Software without restriction, including without limitation the\nrights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit\npersons to whom the Software is furnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all copies or substantial portions of the\nSoftware.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE\nWARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR\nCOPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR\nOTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"}],"content_type":"text/markdown"}